﻿using UnityEngine;
using System.Collections;

public class Level1Script : MonoBehaviour {

	public GUISkin guiSkin;

	//LEVEL 1 ITEM
	private bool is_loot_bag = false;
	private bool is_loot_towel = false;
	private bool is_loot_water = false;
	private bool is_loot_complete = false;

	private GameObject item;
	private PlayerPhysics playerPhysics;
	private GameSettings  gameSettings;
	private LevelTimer levelTimer;

	private GameObject Btn_InstructionGetBag;
	private ClickButton Btn_ClickButton;

	private const string FAILED_BAG = "FAILED ! THE BAG WAS BURNED.";
	private const string FAILED_TIME = "FAILED ! SUFFOCATED.";
	private const string FAILED_INCOMPLETE = "FAILED ! BURNED.";
	private const string FAILED_WRONGDOOR = "FAILED ! WRONG DOOR."; // NOT USED IN LEVEL 1
	private string failedMessage;

	private bool showDialog_001;
	private bool showDialog_002;
	private bool IsPlayerOutside = true;

	private bool showButton_GetBag;

	private bool showWarningDialog_001;
	private bool showFailedMessage;

	void Start () {

		playerPhysics = gameObject.GetComponent<PlayerPhysics> ();
		gameSettings = gameObject.GetComponent<GameSettings> ();
		levelTimer = gameObject.GetComponent<LevelTimer> ();

		if (IsPlayerOutside){
			showDialog_001 = true;
		}	
	}
	
	void Update () {

		GameObject item = playerPhysics.Item;

		if (!IsPlayerOutside && item != null) {

			if (!gameSettings.IsPaused){
			failedMessage = ItemInteraction (item, Input.GetMouseButtonDown (0));
			failedMessage = failedMessage += TimeInteraction (10);
			}

			//RESTART ON EVERY FAILED MOVE
			if (failedMessage != "") {
				gameSettings.IsPaused = true;
				showFailedMessage = true;
			}

		} else if (IsPlayerOutside && item != null) {

			if (Input.GetMouseButtonDown (0) && item.tag == "door"){

				StartCoroutine(DialogSequence());
			}
		}

		if ((item == null || item.tag != "door"))showWarningDialog_001 = false;
	
	}
	IEnumerator DialogSequence()
	{
		showDialog_001 = false;
		yield return new WaitForSeconds(1.5f);
		IsPlayerOutside = false;
		showDialog_002 = true;
		yield return new WaitForSeconds(2);
		showDialog_002 = false;
		showButton_GetBag = true;
		gameSettings.IsPaused = !gameSettings.IsPaused;
	}

	void OnGUI(){

		GUI.skin = guiSkin;

		int y = Screen.height - 40;
		int w = Screen.width;
		int h = 50;


		if (showDialog_001)
			GUI.Label(new Rect(0, y, w, h), "Hey What's happening and where am I? Oh I remember I'm here at Saint Benilde for the Global Game Jam Competition. I guess I have to enter the Theater to look for my teammates.");

		if (showDialog_002)
			GUI.Label(new Rect(0, y, w, h), "Awk! Why there is suddenly an explosion and where are the people?! I have to look my Bag before it gets burned and get out of here right now! or else I'm gonna suffocate in here!. ");

		int buttonWidth = 400;
		int xCenter = (Screen.width / 2 - buttonWidth / 2);

		if (showButton_GetBag) {
			bool ans = GUI.Button(new Rect(xCenter, 250, buttonWidth, 130), "Get your Bag within 10sec\nClick To Continue");
			if (ans){
				levelTimer.DoCountdown = true;
				showButton_GetBag = false;
				gameSettings.IsPaused = !gameSettings.IsPaused;
			}
		}

		if (showWarningDialog_001) {
			GUI.Label(new Rect(0, y, w, h), "adsasdadadasd");
		}

		if (showFailedMessage) {
			bool ans = GUI.Button(new Rect(xCenter, 250, buttonWidth, 130), failedMessage);
			if (ans){
				Application.LoadLevel (gameSettings.LEVEL1);
			}
		}
	}

	private string TimeInteraction(int timeLitmit){

		string failedMessage = "";

		//GET LOOT BAG IN X SECONDS
		if (levelTimer.GetTimeLapse == timeLitmit && !is_loot_bag) {
			failedMessage = FAILED_BAG;
		}else if(levelTimer.GetTimeLapse == (int)levelTimer.SetTimeLimit) {
			failedMessage = FAILED_TIME;
		}

		return failedMessage;
	}

	private string ItemInteraction(GameObject item, bool isClicked){

		string failedMessage = "";

		if (isClicked) {
			if (item.tag == "loot") {
					DestroyItemLoot (item);
			}
			if (item.tag == "door") {

					//INDOOR
					if (is_loot_complete) {
							Debug.Log ("OPEN DOOR");
							Application.LoadLevel (gameSettings.LEVEL2);
					} else {
							//OPENING DOOR , ITEM NOT YET COMPLETED
							failedMessage = FAILED_INCOMPLETE;
					}
			}
		} else {
			if ( !is_loot_complete && item.tag == "door") {
				showWarningDialog_001 = true;
				//EDIT
				//VOICE OVER
			}
		}



		return failedMessage;
	}


	private void DestroyItemLoot(GameObject item){

		switch (item.name) {
			case "loot_bag" : 
				is_loot_bag = true; break;
			case "loot_water" : 
				is_loot_water = true; break;
			case "loot_towel" : 
				is_loot_towel = true; break;
		}

		Destroy(item);

		is_loot_complete = (is_loot_bag && is_loot_water && is_loot_towel) ? true : false;
	}
}